@@ -14,30 +14,37 @@
 namespace morphio {
 
 using namespace enums;
+class DendriticSpine;
 class EndoplasmicReticulum;
 class MitoSection;
 class Mitochondria;
 class Morphology;
 class Section;
+
 template <class T>
 class SectionBase;
+
 class Soma;
 
 namespace Property {
 struct Properties;
 }
 
+/** Functionality for vasculature (blood)  **/
 namespace vasculature {
 class Section;
 class Vasculature;
 }  // namespace vasculature
 
+/** Functionality for reading of morphologies from files  **/
 namespace readers {
 struct DebugInfo;
 class ErrorMessages;
 }  // namespace readers
 
+/** Functionality for mutating(editing) of morphologies  **/
 namespace mut {
+class DendriticSpine;
 class EndoplasmicReticulum;
 class MitoSection;
 class Mitochondria;
