@@ -1,5 +1,4 @@
 #pragma once
-#include <memory>  // std::unique_ptr
 #include <string>  // std::string
 #include <vector>  // std::vector
 
@@ -31,6 +30,7 @@ class MorphologyHDF5
     void _readPerimeters(int);
     void _readMitochondria();
     void _readEndoplasmicReticulum();
+    void _readDendriticSpinePostSynapticDensity();
 
     template <typename T>
     void _read(const std::string& group,
